@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use 5.008001;
 
-our $VERSION = '0.51';
+our $VERSION = '0.52';
 
 use Carp ();
 use URI ();
@@ -118,7 +118,7 @@ sub _default_cb {
 sub prepare_download {
     my ($self, $video_id) = @_;
     Carp::croak "Usage: $self->prepare_download('[video_id|watch_url]')" unless $video_id;
-    $video_id = _video_id($video_id);
+    $video_id = $self->video_id($video_id);
 
     return $self->{cache}{$video_id} if ref $self->{cache}{$video_id} eq 'HASH';
 
@@ -269,8 +269,9 @@ sub _suffix {
     ;
 }
 
-sub _video_id {
-    my $stuff = shift;
+sub video_id {
+    my ($self, $stuff) = @_;
+    return unless $stuff;
     if ($stuff =~ m{/.*?[?&;!](?:v|video_id)=([^&#?=/;]+)}) {
         return $1;
     }
@@ -288,6 +289,16 @@ sub _video_id {
     }
 }
 
+sub playlist_id {
+    my ($self, $stuff) = @_;
+    return unless $stuff;
+    if ($stuff =~ m{/.*?[?&;!]list=PL([^&#?=/;]+)}) {
+        return $1;
+    }
+    $stuff =~ s/^PL//;
+    return $stuff;
+}
+
 1;
 __END__
 
@@ -459,6 +470,14 @@ the URL where the video can be found
 
 Sets and gets LWP::UserAgent object.
 
+=item B<video_id($url)>
+
+Parses given URL and returns video ID.
+
+=item B<playlist_id($url)>
+
+Parses given URL and returns playlist ID.
+
 =item B<get_video_url($video_id)>
 
 =item B<get_title($video_id)>
